@@ -23,6 +23,10 @@ EVENT_FIXTURE_FILENAMES = [
 ]
 
 
+class DummyTransformer(BaseTransformerMixin):
+    required_fields = ('does_not_exist',)
+
+
 @ddt.ddt
 class TransformersTestMixin:
     """
@@ -38,15 +42,19 @@ class TransformersTestMixin:
         UserFactory.create(username='edx')
 
     def test_with_no_field_transformer(self):
-        class DummyTransformer(BaseTransformerMixin):
-            required_fields = ('does_not_exist', )
-
         self.registry.register('test_event')(DummyTransformer)
         with self.assertRaises(ValueError):
             self.registry.get_transformer({
                 'name': 'test_event'
             }).transform()
 
+    def test_required_field_transformer(self):
+        self.registry.register('test_event')(DummyTransformer)
+        with self.assertRaises(ValueError):
+            self.registry.get_transformer({
+                 "name": "edx.course.enrollment.activated"
+                 }).transform()
+
     @abstractmethod
     def compare_events(self, transformed_event, expected_event):
         """
@@ -70,7 +78,8 @@ class TransformersTestMixin:
         if not os.path.isfile(expected_event_file_path):
             return
 
-        with open(input_event_file_path) as current, open(expected_event_file_path) as expected:
+        with open(input_event_file_path, encoding='utf-8') as current, open(
+                expected_event_file_path, encoding='utf-8') as expected:
             original_event = json.loads(current.read())
             expected_event = json.loads(expected.read())
 
