@@ -11,6 +11,7 @@ XAPI_VERB_REGISTERED = 'http://adlnet.gov/expapi/verbs/registered'
 XAPI_VERB_UNREGISTERED = 'http://id.tincanapi.com/verb/unregistered'
 XAPI_VERB_COMPLETED = 'http://adlnet.gov/expapi/verbs/completed'
 XAPI_VERB_PASSED = 'http://adlnet.gov/expapi/verbs/passed'
+XAPI_VERB_FAILED = 'http://adlnet.gov/expapi/verbs/failed'
 XAPI_VERB_EXPERIENCED = 'http://adlnet.gov/expapi/verbs/experienced'
 XAPI_VERB_NAVIGATED = 'https://w3id.org/xapi/dod-isd/verbs/navigated'
 
@@ -73,6 +74,7 @@ PLAYED = 'played'
 PAUSED = 'paused'
 COMPLETED = 'completed'
 PASSED = 'passed'
+FAILED = 'failed'
 SEEKED = 'seeked'
 
 TERMINATED = 'terminated'
